[![Build Status](https://app.travis-ci.com/mkrum/chessplotlib.svg?branch=main)](https://app.travis-ci.com/mkrum/chessplotlib)
[![PyPI
version](https://badge.fury.io/py/chessplotlib.svg)](https://badge.fury.io/py/chessplotlib)
# ♚ chessplotlib
Chess visualizations with matplotlib.

